Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Step Functions.

Actions, resources, and condition keys for AWS Step Functions - Service Authorization Reference

# Actions, resources, and condition keys for AWS Step Functions

AWS Step Functions (service prefix: `states` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Step Functions
- Resource types defined by AWS Step Functions
- Condition keys for AWS Step Functions

## Actions defined by AWS Step Functions

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateActivity | Grants permission to create an activity | Write | activity* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateStateMachine | Grants permission to create a state machine | Write | statemachine* |  | states:PublishStateMachineVersion
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateStateMachineAlias | Grants permission to create a state machine alias | Write | statemachine* |  |
| states:StateMachineQualifier |
DeleteActivity | Grants permission to delete an activity | Write | activity* |  |
DeleteStateMachine | Grants permission to delete a state machine | Write | statemachine* |  |
DeleteStateMachineAlias | Grants permission to delete a state machine alias | Write | statemachine* |  |
| states:StateMachineQualifier |
DeleteStateMachineVersion | Grants permission to delete a state machine version | Write | statemachine* |  |
| states:StateMachineQualifier |
DescribeActivity | Grants permission to describe an activity | Read | activity* |  |
DescribeExecution | Grants permission to describe an execution | Read | execution* |  |
express* |  |
DescribeMapRun | Grants permission to describe a map run | Read | maprun* |  |
DescribeStateMachine | Grants permission to describe a state machine | Read | statemachine* |  |
| states:StateMachineQualifier |
DescribeStateMachineAlias | Grants permission to describe a state machine alias | Read | statemachine* |  |
| states:StateMachineQualifier |
DescribeStateMachineForExecution | Grants permission to describe the state machine for an execution | Read | execution* |  |
GetActivityTask | Grants permission to be used by workers to retrieve a task (with the specified activity ARN) which has been scheduled for execution by a running state machine | Write | activity* |  |
GetExecutionHistory | Grants permission to return the history of the specified execution as a list of events | Read | execution* |  |
ListActivities | Grants permission to list the existing activities | List |  |  |
ListExecutions | Grants permission to list the executions of a state machine | List | maprun* |  |
statemachine* |  |
| states:StateMachineQualifier |
ListMapRuns | Grants permission to list the map runs of an execution | List | execution* |  |
ListStateMachineAliases | Grants permission to list the aliases of a state machine | List | statemachine* |  |
| states:StateMachineQualifier |
ListStateMachineVersions | Grants permission to list the versions of a state machine | List | statemachine* |  |
ListStateMachines | Grants permission to lists the existing state machines | List |  |  |
ListTagsForResource | Grants permission to list tags for an AWS Step Functions resource | List | activity |  |
statemachine |  |
PublishStateMachineVersion | Grants permission to publish a state machine version | Write | statemachine* |  |
SendTaskFailure | Grants permission to report that the task identified by the taskToken failed | Write |  |  |
SendTaskHeartbeat | Grants permission to report to the service that the task represented by the specified taskToken is still making progress | Write |  |  |
SendTaskSuccess | Grants permission to report that the task identified by the taskToken completed successfully | Write |  |  |
StartExecution | Grants permission to start a state machine execution | Write | statemachine* |  |
| states:StateMachineQualifier |
StartSyncExecution | Grants permission to start a Synchronous Express state machine execution | Write | statemachine* |  |
| states:StateMachineQualifier |
StopExecution | Grants permission to stop an execution | Write | execution* |  |
TagResource | Grants permission to tag an AWS Step Functions resource | Tagging | activity |  |
statemachine |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove a tag from an AWS Step Functions resource | Tagging | activity |  |
statemachine |  |
| aws:TagKeys |
UpdateMapRun | Grants permission to update a map run | Write | maprun* |  |
UpdateStateMachine | Grants permission to update a state machine | Write | statemachine* |  | states:PublishStateMachineVersion
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateStateMachineAlias | Grants permission to update a state machine alias | Write | statemachine* |  |
| states:StateMachineQualifier |

## Resource types defined by AWS Step Functions

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
activity | `arn:$ { Partition}:states:$ { Region}:$ { Account}:activity:$ { ActivityName}` | aws:ResourceTag/${TagKey}
execution | `arn:$ { Partition}:states:$ { Region}:$ { Account}:execution:$ { StateMachineName}:$ { ExecutionId}` | aws:ResourceTag/${TagKey}
express | `arn:$ { Partition}:states:$ { Region}:$ { Account}:express:$ { StateMachineName}:$ { ExecutionId}:$ { ExpressId}` |
statemachine | `arn:$ { Partition}:states:$ { Region}:$ { Account}:stateMachine:$ { StateMachineName}` | aws:ResourceTag/${TagKey}
statemachineversion | `arn:$ { Partition}:states:$ { Region}:$ { Account}:stateMachine:$ { StateMachineName}:$ { StateMachineVersionId}` |
statemachinealias | `arn:$ { Partition}:states:$ { Region}:$ { Account}:stateMachine:$ { StateMachineName}:$ { StateMachineAliasName}` |
maprun | `arn:$ { Partition}:states:$ { Region}:$ { Account}:mapRun:$ { StateMachineName}/$ { MapRunLabel}:$ { MapRunId}` |

## Condition keys for AWS Step Functions

AWS Step Functions defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a tag key and value pair that is allowed in the request | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair of a resource | String
aws:TagKeys | Filters access by a list of tag keys that are allowed in the request | ArrayOfString
states:StateMachineQualifier | Filters access by the qualifier of a state machine ARN | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.